lexicons\_builder package
=========================

.. automodule:: lexicons_builder
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   lexicons_builder.graphs
   lexicons_builder.nlp_model_explorer
   lexicons_builder.scrappers
   lexicons_builder.touch_file
   lexicons_builder.wordnet_explorer
